@@ -5,18 +5,19 @@
 #' federal law n. 12.651/2012). The original data comes from the Brazilian
 #' Ministry of Environment (MMA) and can be found at "http://mapas.mma.gov.br/i3geo/datadownload.htm".
 #'
-#' @param year A date number in YYYY format. Defaults to `2012`
+#' @param year Numeric. Year of the data in YYYY format. Defaults to `2012`.
 #' @template simplified
 #' @template showProgress
 #'
 #' @return An `"sf" "data.frame"` object
 #'
 #' @export
-#' @family general area functions
-#' @examples \dontrun{ if (interactive()) {
+#' @family area functions
+#'
+#' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' # Read Brazilian Legal Amazon
 #' a <- read_amazon(year = 2012)
-#'}}
+#'
 read_amazon <- function(year=2012, simplified=TRUE, showProgress=TRUE){
 
   # Get metadata with data url addresses
@@ -30,5 +31,9 @@ read_amazon <- function(year=2012, simplified=TRUE, showProgress=TRUE){
 
   # download files
   temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+
+  # check if download failed
+  if (is.null(temp_sf)) { return(invisible(NULL)) }
+
   return(temp_sf)
 }
