@@ -5,7 +5,7 @@
 #' in  23/11/2017). The original data comes from the Brazilian Institute of Geography
 #' and Statistics (IBGE) and can be found at \url{https://www.ibge.gov.br/geociencias/cartas-e-mapas/mapas-regionais/15974-semiarido-brasileiro.html?=&t=downloads}
 #'
-#' @param year A date number in YYYY format (defaults to 2017)
+#' @param year Numeric. Year of the data in YYYY format. Defaults to `2017`.
 #' @template simplified
 #' @template showProgress
 #'
@@ -13,11 +13,12 @@
 #' @return An `"sf" "data.frame"` object
 #'
 #' @export
-#' @family general area functions
-#' @examples \dontrun{ if (interactive()) {
+#' @family area functions
+#'
+#' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' # Read Brazilian semiarid
 #' a <- read_semiarid(year=2017)
-#'}}
+#'
 read_semiarid <- function(year=2017, simplified=TRUE, showProgress=TRUE){
 
   # Get metadata with data url addresses
@@ -28,6 +29,10 @@ read_semiarid <- function(year=2017, simplified=TRUE, showProgress=TRUE){
 
   # download files
   temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+
+  # check if download failed
+  if (is.null(temp_sf)) { return(invisible(NULL)) }
+
   return(temp_sf)
 
 }
