@@ -12,25 +12,25 @@ test_that("read_municipality", {
   test_2010 <- read_municipality(code_muni=1100205, year=2010)
 
   # check sf object
-  expect_true(is(test_1970, "sf"))
-  expect_true(is(test_2010, "sf"))
+  testthat::expect_true(is(test_1970, "sf"))
+  testthat::expect_true(is(test_2010, "sf"))
 
-  expect_true(is(  read_municipality( year=1970)  , "sf"))
-  expect_true(is(  read_municipality(code_muni=11, year=1970)  , "sf"))
-   # expect_true(is(  read_municipality(code_muni=11, year=1970, simplified = F) , "sf"))
-  # expect_true(is(  read_municipality(code_muni='all', year=1970) , "sf"))
-  # expect_true(is(  read_municipality(code_muni='all', year=1970, simplified = F) , "sf"))
-  expect_true(is(  read_municipality(code_muni='AC', year=1970) , "sf"))
-  expect_true(is(  read_municipality(code_muni=1100205, year=1970) , "sf"))
+  testthat::expect_true(is(  read_municipality( year=1970)  , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni=11, year=1970)  , "sf"))
+   # testthat::expect_true(is(  read_municipality(code_muni=11, year=1970, simplified = F) , "sf"))
+  # testthat::expect_true(is(  read_municipality(code_muni='all', year=1970) , "sf"))
+  # testthat::expect_true(is(  read_municipality(code_muni='all', year=1970, simplified = F) , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni='AC', year=1970) , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni=1100205, year=1970) , "sf"))
 
-  expect_true(is(  read_municipality() , "sf"))
-  expect_true(is(  read_municipality( year=2010) , "sf"))
-  # expect_true(is(  read_municipality(code_muni=11, year=2010) , "sf"))
-  expect_true(is(  read_municipality(code_muni=11, year=2010, simplified = F) , "sf"))
-  # expect_true(is(  read_municipality(code_muni='all', year=2010) , "sf"))
-  # expect_true(is(  read_municipality(code_muni='all', year=2010, simplified = F) , "sf"))
-  expect_true(is(  read_municipality(code_muni='AC', year=2010)  , "sf"))
-  expect_true(is(  read_municipality(code_muni=1200179, year=2010) , "sf"))
+  testthat::expect_true(is(  read_municipality() , "sf"))
+  testthat::expect_true(is(  read_municipality( year=2010) , "sf"))
+  # testthat::expect_true(is(  read_municipality(code_muni=11, year=2010) , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni=11, year=2010, simplified = F) , "sf"))
+  # testthat::expect_true(is(  read_municipality(code_muni='all', year=2010) , "sf"))
+  # testthat::expect_true(is(  read_municipality(code_muni='all', year=2010, simplified = F) , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni='AC', year=2010)  , "sf"))
+  testthat::expect_true(is(  read_municipality(code_muni=1200179, year=2010) , "sf"))
 
 })
 
